# Bongloy Ruby Library

[![CircleCI](https://circleci.com/gh/bongloy/bongloy-ruby.svg?style=svg)](https://circleci.com/gh/bongloy/bongloy-ruby)
[![Coverage Status](https://coveralls.io/repos/github/bongloy/bongloy-ruby/badge.svg?branch=bongloy_compatibility)](https://coveralls.io/github/bongloy/bongloy-ruby?branch=bongloy_compatibility)

This is the official Ruby library for [Bongloy Payment Gateway][bongloy-payment-gateway].
It's a fork of [Stripe's Ruby Library][stripe-ruby-library], built by [Stripe][stripe-payment-gateway] and automatically kept to date by [pull][pull-github-app]. Note that [Bongloy's API][bongloy-api-reference] is mostly compatible with [Stripe's API][stripe-api-reference], however not all features of Stripe are implemented in Bongloy. Refer to the [Bongloy Documentation][bongloy-documentation] for more information. We thank Stripe for providing and maintaining this awesome library [free and open source][stripe-open-source-license].

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'bongloy'
```

And then execute:

    $ bundle install

Or install it yourself as:

    $ gem install bongloy

## Usage

The library needs to be configured with your account's secret key which is
available in your [Bongloy Dashboard][bongloy-api-keys]. Set `Bongloy.api_key` to its
value:

```ruby
require "bongloy"
Bongloy.api_key = "sk_test_..."

# list charges
Bongloy::Charge.list()

# retrieve single charge
Bongloy::Charge.retrieve(
  "6f3c1e38-d8a9-49c1-86b8-886c2b66eedb"
)
```

### Per-request Configuration

For apps that need to authenticate on behalf of another account during the lifetime of a process, like
one that uses [Bongloy Connect][bongloy-connect], it's also possible to set a
per-request account:

```ruby
require "bongloy"

Bongloy::Charge.list(
  {},
  {
    api_key: "sk_test_...",
    bongloy_account: "c756a678-0f2b-4b81-a8f1-8bb2ed80ece5"
  }
)

Bongloy::Charge.retrieve(
  "6f3c1e38-d8a9-49c1-86b8-886c2b66eedb",
  {
    api_key: "sk_test_...",
    bongloy_account: "c756a678-0f2b-4b81-a8f1-8bb2ed80ece5"
  }
)
```

[bongloy-api-keys]: https://sandbox.bongloy.com/dashboard/api_keys
[bongloy-payment-gateway]: https://www.bongloy.com
[stripe-ruby-library]: https://github.com/stripe/stripe-ruby
[stripe-payment-gateway]: https://stripe.com
[pull-github-app]: https://github.com/wei/pull
[bongloy-documentation]: https://sandbox.bongloy.com/documentation
[stripe-api-reference]: https://stripe.com/docs/api
[bongloy-api-reference]: https://sandbox.bongloy.com/documentation#bongloy-api-reference
[stripe-open-source-license]: https://github.com/stripe/stripe-ruby/blob/master/LICENSE
[bongloy-connect]: https://sandbox.bongloy.com/documentation#bongloy-connect
